@@ -1,6 +1,6 @@
 /* -*- mode: C; c-file-style: "gnu"; indent-tabs-mode: nil; -*- */
 /*
- * Copyright (C) 2011, 2012, 2013, 2014 Red Hat, Inc.
+ * Copyright (C) 2011, 2012, 2013 Red Hat, Inc.
  *
  * This library is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -107,7 +107,6 @@ build_authorization_uri (GoaOAuth2Provider  *provider,
 
   uri = g_strdup_printf ("%s"
                           "?response_type=token"
-                          "&display=popup"
                           "&redirect_uri=%s"
                           "&client_id=%s"
                           "&scope=%s",
@@ -121,7 +120,7 @@ build_authorization_uri (GoaOAuth2Provider  *provider,
 static const gchar *
 get_authorization_uri (GoaOAuth2Provider *provider)
 {
-  return "https://www.facebook.com/dialog/oauth";
+  return "https://m.facebook.com/dialog/oauth";
 }
 
 static const gchar *
@@ -209,7 +208,7 @@ get_identity_sync (GoaOAuth2Provider  *provider,
       g_set_error (error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED,
-                   _("Expected status 200 when requesting guid, instead got status %d (%s)"),
+                   _("Expected status 200 when requesting your identity, instead got status %d (%s)"),
                    rest_proxy_call_get_status_code (call),
                    rest_proxy_call_get_status_message (call));
       goto out;
@@ -394,6 +393,8 @@ show_account (GoaProvider         *provider,
   goa_util_add_account_info (grid, row++, object);
 
   goa_util_add_row_switch_from_keyfile_with_blurb (grid, row++, object,
+                                                   /* Translators: This is a label for a series of
+                                                    * options switches. For example: “Use for Mail”. */
                                                    _("Use for"),
                                                    "chat-disabled",
                                                    _("C_hat"));
