@@ -962,7 +962,7 @@ on_web_view_navigation_policy_decision_requested (WebKitWebView             *web
       g_set_error (&priv->error,
                    GOA_ERROR,
                    GOA_ERROR_NOT_AUTHORIZED,
-                   _("Authorization response was \"%s\""),
+                   _("Authorization response was ‘%s’"),
                    oauth2_error);
       response_id = GTK_RESPONSE_CLOSE;
     }
@@ -1386,7 +1386,7 @@ goa_oauth2_provider_refresh_account (GoaProvider  *_provider,
       g_set_error (error,
                    GOA_ERROR,
                    GOA_ERROR_FAILED,
-                   _("Was asked to login as %s, but logged in as %s"),
+                   _("Was asked to log in as %s, but logged in as %s"),
                    existing_identity,
                    priv->identity);
       goto out;
